@@ -1,6 +1,7 @@
 from pathlib import Path
+from typing import Tuple
 
-ERRORS = (
+ERRORS: Tuple[str, ...] = (
     "compiler lacks",
     "no configuration exists",
     "not found",
@@ -14,7 +15,7 @@ class LogParser:
         self.errors = 0
         self.warnings = 0
 
-    def parse(self, filepath: Path):
+    def parse(self, filepath: Path) -> None:
         for orig_line in filepath.open("r", errors="ignore"):
             line = orig_line.lower()
             if "error:" in line or any([s in line for s in ERRORS]):
