@@ -67,6 +67,8 @@ class Runtime(ConfigurableObject):
     * **environment**: extra environment variables to be used for all commands
       ran by this runtime. Type: `dict` with `str` keys and values; defaults to
       an empty dict.
+    * **caps**: additional capabilities needed by the container ran by this runtime.
+      Type: `list` with `str`; defaults to an empty list.
     """
 
     basedir = "runtime"
@@ -111,6 +113,7 @@ class Runtime(ConfigurableObject):
         self.source_dir: Path = Path.cwd()
         self.output_dir: Optional[Path] = None
         self.environment = {}
+        self.caps: Optional[list] = []
 
     def __init_config__(self):
         self.toolchains = Toolchain.supported()
@@ -325,6 +328,7 @@ class Image:
         target_hosts="",
         target_skip="",
         packages="",
+        rebuild_targets="",
         install_options="",
         extra_apt_repo=None,
         extra_apt_repo_key=None,
@@ -343,6 +347,7 @@ class Image:
         self.packages = split(packages)
         self.install_options = install_options
         self.rebuild = rebuild
+        self.rebuild_targets = splitmap(rebuild_targets)
         self.extra_apt_repo = extra_apt_repo
         self.extra_apt_repo_key = extra_apt_repo_key
 
@@ -376,6 +381,9 @@ class ContainerRuntime(Runtime):
                         target, "cross-" + image.kind
                     )
                     cross_config["hosts"] = image.target_hosts.get(target, image.hosts)
+                    cross_config["rebuild"] = image.rebuild_targets.get(
+                        target, image.rebuild
+                    )
                     cross_config["skip_build"] = target in image.target_skip
                     cross_image = Image(
                         name=f"{target}_{image.name}", group=group, **cross_config
@@ -437,6 +445,7 @@ class ContainerRuntime(Runtime):
 
     def start_container(self):
         env = (f"--env={k}={v}" for k, v in self.environment.items())
+        caps = (f"--cap-add={cap}" for cap in self.caps)
 
         user_opts = self.get_user_opts()
         extra_opts = self.__get_extra_opts__()
@@ -448,6 +457,7 @@ class ContainerRuntime(Runtime):
             "--detach",
             "--env=KBUILD_BUILD_USER=tuxmake",
             *env,
+            *caps,
             *user_opts,
             *self.get_volume_opts(),
             f"--workdir={self.source_dir}",
